@@ -8,7 +8,7 @@ use File::Spec();
 eval        { require YAML::Syck; YAML::Syck->import(); 1 }
     or eval { require YAML;       YAML->import();       1 }
     or die "ERROR: "
-    . "YAML::Syck or YAML needs to be installed to use this example browser\n\n";
+    . "YAML::Syck or YAML needs to be installed to use this example\n\n";
 
 my $config = Config::Loader->new( get_path('config_dev') );
 my $path = shift @ARGV || '';
